#!/usr/bin/env python

# tests for the Chicken Panda3d exporter for Blender
#
# requirements:
# - A blender executable in your path
# - Panda3d installed
#
# doc for the unittest module: http://docs.python.org/lib/minimal-example.html
#
# author: Simon Groenewolt
#

import os
import subprocess
import unittest

# Panda3d related imports
from pandac.PandaModules import Filename
from pandac.PandaModules import EggData
# from pandac.PandaModules import EggVertex
# from pandac.PandaModules import EggPolygon
# from pandac.PandaModules import EggGroup

class TestChickenExporterMeshes(unittest.TestCase):

	def setUp(self):

		# check if deleted
		os.environ['PYTHONPATH'] = os.path.abspath('../script/')
		retcode = subprocess.call(["blender", "-b", "export-mesh-test.blend", "-P", "../script/chicken_export.py"])

		# read egg file
		self.eggdata = EggData()
		self.eggdata.read(Filename("export-mesh-test.egg"))
		# make sure something is in there
		self.assert_(self.eggdata.size() > 0)

	def tearDown(self):
		os.remove("export-mesh-test.egg")

	def testMesh(self):
		"""One element named 'Cube1' should be in the egg file"""
		cube = self.eggdata.findChild("Cube1")
		self.assert_(cube != None)


class TestChickenExporterEmpties(unittest.TestCase):

	def setUp(self):

		# check if deleted
		os.environ['PYTHONPATH'] = os.path.abspath('../script/')
		retcode = subprocess.call(["blender", "-b", "export-empty-test.blend", "-P", "../script/chicken_export.py"])

		# read egg file
		self.eggdata = EggData()
		self.eggdata.read(Filename("export-empty-test.egg"))
		# make sure something is in there
		self.assert_(self.eggdata.size() > 0)

	def tearDown(self):
		os.remove("export-empty-test.egg")


	def testEmpty(self):
		"""One empty should be present at the root level of the egg file"""
		empty = self.eggdata.findChild("Empty")
		self.assert_(empty != None)


	def testParentedEmpty(self):
		"""'Cube2' should be present at the root level and have Empty.001 parented to it"""
		cube = self.eggdata.findChild("Cube2")
		self.assert_(cube != None)
		parentedEmpty = cube.findChild("Empty.001")
		self.assert_(parentedEmpty != None)


if __name__ == '__main__':
	unittest.main()
